@@ -31,11 +31,17 @@ query_bndespar_desimbursements <- function(year = 'all') {
 
       suppressWarnings({
 
-      df <- readr::read_csv2(link, locale = readr::locale(encoding = "latin1"), show_col_types = FALSE,
-                             skip = 4) |>
-        janitor::clean_names() |>
-        dplyr::filter(ano %in% year)
+      tryCatch({
+        df <- readr::read_csv2(link, locale = readr::locale(encoding = "latin1"), show_col_types = FALSE,
+                               skip = 4) |>
+          janitor::clean_names() |>
+          dplyr::filter(ano %in% year)},
+      # em caso de erro, interrompe a função e mostra msg de erro
 
+      error = function(e) {
+        message("Error downloading file. Try again later.", e$message)
+        stop("Error downloading file.")  }
+      )
       })
 
       message("Completed data query.")
